About — brokerlso 0.0.1 documentation

# About

brokerlso is a small library to create parts of Qpid Management Framework (QMF) version 2 messages.

Legacy qpid-python and associated packages provided the ability to manage an Apache Qpid broker. The newer AMQP messaging toolkit, Qpid Proton, does not provide the same level of functionality.

brokerlso plugs in the gap by being focused solely on creating the parts of an AMQP message that relate to QMF commands.

Look at tests and examples for more information on how to use brokerlso.

## Name

Why brokerlso? It has two parts: Broker and LSO. Broker refers to the Apache Qpid broker. LSO refers to Landing Signal Officer. brokerlso is meant to create QMFv2 messages to manage a Qpid broker.